@@ -1,13 +1,12 @@
 """Factory functions for creating the pyscal objects"""
 
 import logging
-
-import os
-import six
+from pathlib import Path
 
 import pandas as pd
 import numpy as np
 import xlrd
+import openpyxl
 
 from pyscal.utils import capillarypressure
 from .wateroil import WaterOil
@@ -17,7 +16,6 @@ from .wateroilgas import WaterOilGas
 from .scalrecommendation import SCALrecommendation
 from .pyscallist import PyscalList
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
@@ -600,43 +598,53 @@ class PyscalFactory(object):
 
         Returns:
             pd.DataFrame. To be handed over to pyscal list factory methods.
+            Empty dataframe in case of errors (messages will be logged).
         """
-        if isinstance(inputfile, str) and os.path.exists(inputfile):
-            if inputfile.lower().endswith("csv") and sheet_name is not None:
+        if isinstance(inputfile, (str, Path)) and Path(inputfile).is_file():
+            tabular_file_format = infer_tabular_file_format(inputfile)
+            if not tabular_file_format:
+                # Error message emitted by infer_file_format()
+                return pd.DataFrame()
+
+            if tabular_file_format == "csv" and sheet_name is not None:
                 logger.warning(
                     "Sheet name only relevant for XLSX files, ignoring %s", sheet_name
                 )
-            try:
-                if sheet_name:
-                    input_df = pd.read_excel(inputfile, sheet_name=sheet_name)
-                    logger.info("Parsed XLSX file %s, sheet %s", inputfile, sheet_name)
-                else:
-                    input_df = pd.read_excel(inputfile)
-                    logger.info("Parsed XLSX file %s", inputfile)
-            except xlrd.XLRDError as xlserror:
-                if inputfile.lower().endswith("xlsx") or inputfile.lower().endswith(
-                    "xls"
-                ):
-                    logger.error(xlserror)
+            excel_engines = {"xls": "xlrd", "xlsx": "openpyxl"}
+            if sheet_name:
                 try:
-                    input_df = pd.read_csv(inputfile, skipinitialspace=True)
-                    logger.info("Parsed CSV file %s", inputfile)
-                except pd.errors.ParserError as csverror:
-                    logger.error("Could not parse %s as XLSX or CSV", inputfile)
-                    logger.error("Error message from csv-parser: %s", str(csverror))
-                    input_df = pd.DataFrame()
-                except ValueError:
-                    # We end here when we use csv reader on xls files, that
-                    # means that xls parsing failed in the first place. Other
-                    # error messages have been, and will be printed.
-                    input_df = pd.DataFrame()
+                    input_df = pd.read_excel(
+                        inputfile,
+                        sheet_name=sheet_name,
+                        engine=excel_engines[tabular_file_format],
+                    )
+                    logger.info(
+                        "Parsed %s file %s, sheet %s",
+                        tabular_file_format.upper(),
+                        inputfile,
+                        sheet_name,
+                    )
+                except KeyError as error:
+                    logger.error("Non-existing sheet-name %s provided?", sheet_name)
+                    logger.error(str(error))
+                    return pd.DataFrame()
+            elif tabular_file_format.startswith("xls"):
+                input_df = pd.read_excel(
+                    inputfile, engine=excel_engines[tabular_file_format]
+                )
+                logger.info("Parsed %s file %s", tabular_file_format.upper(), inputfile)
+            else:
+                input_df = pd.read_csv(inputfile, skipinitialspace=True)
+                logger.info("Parsed CSV file %s", inputfile)
+
         elif isinstance(inputfile, pd.DataFrame):
             input_df = inputfile
         else:
-            if isinstance(inputfile, str) and not os.path.exists(inputfile):
+            if isinstance(inputfile, str) and not Path(inputfile).is_file():
                 raise IOError("File not found " + str(inputfile))
             raise ValueError("Unsupported argument " + str(inputfile))
         assert isinstance(input_df, pd.DataFrame)
+
         if input_df.empty:
             logger.error("Relperm input dataframe is empty!")
 
@@ -720,7 +728,7 @@ class PyscalFactory(object):
         )
 
         # Check that we are able to make something out of the first row:
-        firstrow = input_df.loc[0, :]
+        firstrow = input_df.iloc[0, :]
         error = False
         try:
             wo_ok = sufficient_water_oil_params(firstrow)
@@ -824,7 +832,7 @@ class PyscalFactory(object):
         Returns:
             PyscalList, consisting of either WaterOil, GasOil or WaterOilGas objects
         """
-        params = relperm_params_df.loc[0, :]  # first row
+        params = relperm_params_df.iloc[0, :]  # first row
         water_oil = sufficient_water_oil_params(params)
         gas_oil = sufficient_gas_oil_params(params)
         gas_water = sufficient_gas_water_params(params)
@@ -1039,7 +1047,7 @@ def filter_nan_from_dict(params):
     """
     cleaned_params = {}
     for key, value in params.items():
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             cleaned_params[key] = value
         else:
             if not np.isnan(value):
@@ -1047,6 +1055,47 @@ def filter_nan_from_dict(params):
     return cleaned_params
 
 
+def infer_tabular_file_format(filename):
+    """Determine the file format of a file containing tabular data,
+    distinguishes between csv, xls and xlsx
+
+    Args:
+        filename (str): Path to file, possibley pathlib Path object.
+
+    Returns:
+        str: One of "csv", "xlsx" or "xls". Empty string if nothing found out.
+    """
+    try:
+        pd.read_excel(filename, engine="openpyxl")
+        return "xlsx"
+    except (ValueError, OSError, openpyxl.utils.exceptions.InvalidFileException):
+        # < Pandas 1.2, we get InvalidFileException from openpyxl
+        # >= Pandas 1.2.0: CSV gives ValueError,
+        #                  XLS gives OSError
+        pass
+    try:
+        pd.read_excel(filename, engine="xlrd")
+        return "xls"
+    except (ValueError, xlrd.biffh.XLRDError):
+        # We get here for both CSV and XLSX files.
+        pass
+    try:
+        dframe = pd.read_csv(filename)
+        if not dframe.empty:
+            return "csv"
+    except UnicodeDecodeError:
+        # (xls and xlsx files)
+        pass
+    except (pd.errors.ParserError, pd.errors.EmptyDataError) as csverror:
+        logger.error("Message from CSV parser: %s", str(csverror))
+        # (Some text file that is not CSV)
+
+    logger.error(
+        "Impossible to infer file format for %s, not CSV/XLS/XLSX", str(filename)
+    )
+    return ""
+
+
 def check_deprecated(params):
     """Check for deprecated parameter names
 
