@@ -1,9 +1,6 @@
 """ Representing a GasOil object """
-from __future__ import division, absolute_import
-from __future__ import print_function
 
 import logging
-import six
 
 import numpy as np
 import pandas as pd
@@ -16,7 +13,6 @@ from pyscal.utils.string import df2str, comment_formatter
 from pyscal.constants import EPSILON as epsilon
 from pyscal.constants import SWINTEGERS, MAX_EXPONENT
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
@@ -77,12 +73,12 @@ class GasOil(object):
         assert -epsilon < sgcr < 1
         assert -epsilon < swl < 1
         assert -epsilon < sorg < 1
-        if not isinstance(tag, six.string_types):
+        if not isinstance(tag, str):
             tag = ""
         if krgendanchor is None:
             krgendanchor = ""
 
-        assert isinstance(krgendanchor, six.string_types)
+        assert isinstance(krgendanchor, str)
 
         h_min = 1.0 / float(SWINTEGERS)
         if h < h_min:
