@@ -1,20 +1,14 @@
 """Container class for list of Pyscal objects"""
 
-from __future__ import division, absolute_import
-from __future__ import print_function
-
-import os
-
+from pathlib import Path
 import logging
 
-import six
 import pandas as pd
 
 from pyscal import WaterOil, GasOil, GasWater, WaterOilGas, SCALrecommendation
 
 PYSCAL_OBJECTS = [WaterOil, GasOil, GasWater, WaterOilGas, SCALrecommendation]
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
@@ -225,11 +219,8 @@ class PyscalList(object):
                 len(self),
                 filename,
             )
-            directory = os.path.dirname(filename)
-            if directory and not os.path.exists(directory):
-                os.makedirs(directory)
-            with open(filename, "w") as file_h:
-                file_h.write(six.ensure_str(family_1_str))
+            Path(filename).parent.mkdir(exist_ok=True, parents=True)
+            Path(filename).write_text(family_1_str, encoding="utf-8")
         return family_1_str
 
     def dump_family_2(self, filename=None):
@@ -262,11 +253,8 @@ class PyscalList(object):
                 len(self),
                 filename,
             )
-            directory = os.path.dirname(filename)
-            if directory and not os.path.exists(directory):
-                os.makedirs(directory)
-            with open(filename, "w") as file_h:
-                file_h.write(six.ensure_str(family_2_str))
+            Path(filename).parent.mkdir(exist_ok=True, parents=True)
+            Path(filename).write_text(family_2_str, encoding="utf-8")
         return family_2_str
 
     def interpolate(self, int_params_wo, int_params_go=None, h=None):
@@ -351,11 +339,8 @@ class PyscalList(object):
                 else:
                     string += outputter(header=False)
         if write_to_filename:
-            directory = os.path.dirname(write_to_filename)
-            if directory and not os.path.exists(directory):
-                os.makedirs(directory)
-            with open(write_to_filename, "w") as file_h:
-                file_h.write(six.ensure_str(string))
+            Path(write_to_filename).parent.mkdir(parents=True, exist_ok=True)
+            Path(write_to_filename).write_text(string, encoding="utf-8")
         return string
 
     def SWOF(self, write_to_filename=None):
