@@ -1,13 +1,6 @@
 """Test the PyscalFactory module"""
-# -*- encoding: utf-8 -*-
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
-
-import six
+from pathlib import Path
 
 import numpy as np
 import pandas as pd
@@ -468,13 +461,9 @@ def test_factory_wateroilgas_wo():
 
 def test_load_relperm_df(tmpdir):
     """Test loading of dataframes with validation from excel or from csv"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
+    testdir = Path(__file__).absolute().parent
 
-    scalfile_xls = testdir + "/data/scal-pc-input-example.xlsx"
+    scalfile_xls = testdir / "data/scal-pc-input-example.xlsx"
 
     scaldata = PyscalFactory.load_relperm_df(scalfile_xls)
     with pytest.raises(IOError):
@@ -520,14 +509,14 @@ def test_load_relperm_df(tmpdir):
     with pytest.raises(ValueError):
         PyscalFactory.load_relperm_df(mergedcase)
 
-    relpermfile_xls = testdir + "/data/relperm-input-example.xlsx"
+    relpermfile_xls = testdir / "data/relperm-input-example.xlsx"
     relpermdata = PyscalFactory.load_relperm_df(relpermfile_xls)
     assert "TAG" in relpermdata
     assert "SATNUM" in relpermdata
     assert "satnum" not in relpermdata  # always converted to upper-case
     assert len(relpermdata) == 3
     swof_str = PyscalFactory.create_pyscal_list(relpermdata, h=0.2).SWOF()
-    assert six.ensure_str("Åre 1.8") in six.ensure_str(swof_str)
+    assert "Åre 1.8" in swof_str
     assert "SATNUM 2" in swof_str  # Autogenerated in SWOF, generated by factory
     assert "SATNUM 3" in swof_str
     assert "foobar" in swof_str  # Random string injected in xlsx.
@@ -545,16 +534,11 @@ def test_xls_factory():
     This test function predates the load_relperm_df() function, but can
     still be in here.
     """
+    testdir = Path(__file__).absolute().parent
 
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
+    xlsxfile = testdir / "data/scal-pc-input-example.xlsx"
 
-    xlsxfile = testdir + "/data/scal-pc-input-example.xlsx"
-
-    scalinput = pd.read_excel(xlsxfile).set_index(["SATNUM", "CASE"])
+    scalinput = pd.read_excel(xlsxfile, engine="openpyxl").set_index(["SATNUM", "CASE"])
 
     for ((satnum, _), params) in scalinput.iterrows():
         assert satnum
@@ -571,13 +555,9 @@ def test_xls_factory():
 
 def test_create_lists():
     """Test the factory methods for making pyscal lists"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
+    testdir = Path(__file__).absolute().parent
 
-    scalfile_xls = testdir + "/data/scal-pc-input-example.xlsx"
+    scalfile_xls = testdir / "data/scal-pc-input-example.xlsx"
     scaldata = PyscalFactory.load_relperm_df(scalfile_xls)
     scalrec_list = PyscalFactory.create_scal_recommendation_list(scaldata)
     assert len(scalrec_list) == 3
@@ -605,7 +585,6 @@ def test_create_lists():
 
 def test_scalrecommendation():
     """Testing making SCAL rec from dict of dict."""
-
     pyscal_factory = PyscalFactory()
 
     scal_input = {
@@ -643,7 +622,6 @@ def test_scalrecommendation():
 
 def test_scalrecommendation_gaswater():
     """Testing making SCAL rec from dict of dict for gaswater input"""
-
     pyscal_factory = PyscalFactory()
 
     scal_input = {
@@ -661,15 +639,10 @@ def test_scalrecommendation_gaswater():
 
 def test_xls_scalrecommendation():
     """Test making SCAL recommendations from xls data"""
+    testdir = Path(__file__).absolute().parent
 
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
-
-    xlsxfile = testdir + "/data/scal-pc-input-example.xlsx"
-    scalinput = pd.read_excel(xlsxfile).set_index(["SATNUM", "CASE"])
+    xlsxfile = testdir / "data/scal-pc-input-example.xlsx"
+    scalinput = pd.read_excel(xlsxfile, engine="openpyxl").set_index(["SATNUM", "CASE"])
     print(scalinput)
     for satnum in scalinput.index.levels[0].values:
         dictofdict = scalinput.loc[satnum, :].to_dict(orient="index")
@@ -942,3 +915,38 @@ def test_corey_let_mix():
     assert "Corey krow" in swof1
     assert "LET krw" in swof2
     assert "Corey krow" in swof2
+
+
+def test_infer_tabular_file_format(tmpdir, caplog):
+
+    testdir = Path(__file__).absolute().parent
+    assert (
+        factory.infer_tabular_file_format(testdir / "data/scal-pc-input-example.xlsx")
+        == "xlsx"
+    )
+    assert (
+        factory.infer_tabular_file_format(
+            str(testdir / "data/scal-pc-input-example.xlsx")
+        )
+        == "xlsx"
+    )
+    assert (
+        factory.infer_tabular_file_format(testdir / "data/scal-pc-input-example.xls")
+        == "xls"
+    )
+    tmpdir.chdir()
+    pd.DataFrame([{"SATNUM": 1, "NW": 2}]).to_csv("some.csv", index=False)
+    assert factory.infer_tabular_file_format("some.csv") == "csv"
+
+    Path("empty.csv").write_text("")
+    assert factory.infer_tabular_file_format("empty.csv") == ""
+    # Ensure Pandas's error message got through:
+    assert "No columns to parse from file" in caplog.text
+    # Ensure factory.py's error message got through:
+    assert "Impossible to infer file format for empty.csv" in caplog.text
+
+    # Write 10 random bytes to a file, this should with very
+    # little probability give a valid xlsx/xls/csv file.
+    Path("wrong.csv").write_bytes(os.urandom(10))
+    assert factory.infer_tabular_file_format("wrong.csv") == ""
+    assert "Impossible to infer file format for wrong.csv" in caplog.text
