@@ -1,9 +1,5 @@
 """Test module for the GasWater object"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import numpy as np
 
 from hypothesis import given, settings
