@@ -1,10 +1,6 @@
 """Test the PyscalList module"""
-# -*- encoding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
-import os
+from pathlib import Path
 
 import numpy as np
 import pandas as pd
@@ -64,17 +60,20 @@ def test_pyscallist_basic():
     assert len(p_list) == 2
 
 
-def test_load_scalrec():
+def test_load_scalrec(tmpdir):
     """Load a SATNUM range from xlsx"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
+    testdir = Path(__file__).absolute().parent
 
     scalrec_data = PyscalFactory.load_relperm_df(
-        testdir + "/data/scal-pc-input-example.xlsx"
+        testdir / "data/scal-pc-input-example.xlsx"
     )
+
+    # Also check that we can read the old excel format
+    scalrec_data_legacy_xls = PyscalFactory.load_relperm_df(
+        testdir / "data/scal-pc-input-example.xls"
+    )
+    pd.testing.assert_frame_equal(scalrec_data, scalrec_data_legacy_xls)
+
     scalrec_list = PyscalFactory.create_scal_recommendation_list(scalrec_data)
     wog_list = scalrec_list.interpolate(-0.3)
 
@@ -105,17 +104,20 @@ def test_load_scalrec():
     with pytest.raises(ValueError):
         scalrec_list.interpolate(1, [-1, 1, 0, 0])
 
+    # Test slicing the scalrec to base, this is relevant for
+    # API usage.
+    base_data = scalrec_data[scalrec_data["CASE"] == "base"].drop("CASE", axis=1)
+    PyscalFactory.load_relperm_df(base_data)  # Ensure no errors.
+    pyscal_list = PyscalFactory.create_pyscal_list(base_data)
+    assert "LET" in pyscal_list.dump_family_1()
+
 
 def test_df():
     """Test dataframe dumps"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
+    testdir = Path(__file__).absolute().parent
 
     scalrec_data = PyscalFactory.load_relperm_df(
-        testdir + "/data/scal-pc-input-example.xlsx"
+        testdir / "data/scal-pc-input-example.xlsx"
     )
     scalrec_list = PyscalFactory.create_scal_recommendation_list(scalrec_data)
     wog_list = scalrec_list.interpolate(-0.3)
@@ -206,14 +208,10 @@ def test_df():
 
 def test_load_scalrec_tags():
     """Test tag handling for a SCAL recommendation with SATNUM range"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
+    testdir = Path(__file__).absolute().parent
 
     scalrec_data = PyscalFactory.load_relperm_df(
-        testdir + "/data/scal-pc-input-example.xlsx"
+        testdir / "data/scal-pc-input-example.xlsx"
     )
     scalrec_list = PyscalFactory.create_scal_recommendation_list(scalrec_data)
 
@@ -270,14 +268,10 @@ def test_load_scalrec_tags():
 
 def test_dump():
     """Test dumping Eclipse include data to file"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
+    testdir = Path(__file__).absolute().parent
 
     relperm_data = PyscalFactory.load_relperm_df(
-        testdir + "/data/relperm-input-example.xlsx"
+        testdir / "data/relperm-input-example.xlsx"
     )
     pyscal_list = PyscalFactory.create_pyscal_list(relperm_data)
 
@@ -603,9 +597,7 @@ def test_explicit_df():
 
 
 def test_comments_df():
-    """Test that we support a tag column in the dataframe, and
-    that we are able to handle UTF-8 stuff nicely in py2-3
-    """
+    """Test that we support a tag column in the dataframe."""
     dframe = pd.DataFrame(
         columns=["SATNUM", "tag", "Nw", "Now", "ng", "nOG"],
         data=[[1, "thisisacomment", 2, 2, 2, 2]],
