@@ -1,9 +1,5 @@
 """Test module for SCAL recommendation objects"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import pandas as pd
 
 from hypothesis import given, settings
