@@ -1,9 +1,5 @@
 """Test module for relperm interpolation support code"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import numpy as np
 import pandas as pd
 
