@@ -1,9 +1,5 @@
 """Test module for the saturation ranges in WaterOil objects"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from hypothesis import given, settings
 import hypothesis.strategies as st
 
