@@ -1,9 +1,5 @@
 """Test module for the WaterOilGas object"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from pyscal import WaterOilGas, WaterOil, GasOil
 
 
